海上钢琴师 (豆瓣)
Description: 海上钢琴师电影简介和剧情介绍,海上钢琴师影评、图片、预告片、影讯、论坛、在线购票
Keywords: 海上钢琴师,La leggenda del pianista sull'oceano,海上钢琴师影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.13豆瓣电影Top250

# 海上钢琴师 La leggenda del pianista sull'oceano (1998)

更新描述或海报

导演: 朱塞佩·托纳多雷
编剧: 亚利桑德罗·巴里克 / 朱塞佩·托纳多雷
主演: 蒂姆·罗斯 / 普路特·泰勒·文斯 / 比尔·努恩 / 克兰伦斯·威廉姆斯三世 / 梅兰尼·蒂埃里 / 皮特·沃恩 / 尼尔·奥布赖恩 / 阿尔贝托·巴斯克斯 / 加布里埃莱·拉维亚 / 科里·巴克 / 西德尼·科尔 / Luigi De Luca / 尼古拉·迪·平托 / 费米·依鲁福祖 / 伊斯顿·盖奇 / 凯文·麦克纳利 / 布莱恩·普林格 / 沙拉·鲁宾 / 希思科特·威廉姆斯 / 阿妮妲·扎格利亚 / 安吉洛·迪洛雷塔
类型: 剧情 / 音乐
制片国家/地区: 意大利
语言: 英语 / 法语 / 意大利语
上映日期: 2019-11-15(中国大陆) / 1998-10-28(意大利)
片长: 165分钟 / 120分钟(法国版) / 169分钟(加长版) / 125分钟(中国大陆)
又名: 声光伴我飞(港) / 一九零零的传奇 / 1900海上钢琴师 / 传奇1900 / The Legend of 1900 / The Legend Of The Pianist On The Ocean
IMDb: tt0120731
豆瓣评分
引用
9.3
1601368人评价
5星
70.8%
4星
24.3%
3星
4.4%
2星
0.4%
1星
0.2%
好友评分
你关注的人看过这部作品的平均分
8.3
6人评价
好于 99% 音乐片
好于 99% 剧情片
想看 看过
评价:
推荐

## 海上钢琴师的剧情简介 · · · · · ·

本片讲述了一个钢琴天才传奇的一生。
1900年，Virginian号豪华邮轮上，一个孤儿被遗弃在头等舱，由船上的水手抚养长大，取名1900（蒂姆•罗斯 饰）。1900慢慢长大，显示出了无师自通的非凡钢琴天赋，在船上的乐队表演钢琴，每个听过他演奏的人，都被深深打动。爵士乐鼻祖杰尼听说了1900的高超技艺，专门上船和他比赛，最后自叹弗如，黯然离去。
可惜，这一切的事情都发生在海上，1900从来不愿踏上陆地，直到有一天，他爱上了一个女孩，情愫在琴键上流淌。他会不会为了爱情，踏上陆地开始新的生活，用他的琴声惊艳世界？他将怎样谱写自己非凡的人生。 ©豆瓣

## 海上钢琴师的演职员 · · · · · · ( 全部 39 )

- 朱塞佩·托纳多雷 导演
- 蒂姆·罗斯 饰 1900 Danny Boodmann T.D. Lemon Nineteen Hundred '1900'
- 普路特·泰勒·文斯 饰 麦克斯 Max Tooney
- 比尔·努恩 饰 丹尼 Danny Boodmann
- 克兰伦斯·威廉姆斯三世 饰 莫顿 'Jelly Roll' Morton
- 梅兰尼·蒂埃里 饰 女孩 The Girl

## 海上钢琴师的视频和图片 · · · · · · ( 预告片8 | 视频评论1 · 添加 | 图片1275 · 添加 )

## 海上钢琴师的获奖情况 · · · · · · ( 全部 )

- 第57届金球奖
- 电影类 最佳原创配乐
- 恩尼奥·莫里康内

## 喜欢这部电影的人也喜欢 · · · · · ·

  放牛班的春天

  音乐之声

  波西米亚狂想曲

  爆裂鼓手

  爱乐之城

  曾经

  再次出发之纽约遇见你

  一一

  海盗电台

  八月迷情

我要写短评

## 海上钢琴师的短评 · · · · · · ( 全部 323561 条 )

热门 / 最新 / 好友

### 17295 有用 Zuschauerin 看过 2007-03-12 18:11:47

我总觉得这是一个真实的故事，因为他的懦弱，懦弱得真实。

### 4547 有用 朝暮雪 看过 2012-08-07 15:43:51

在船上出生，在船上死亡，他是一个从来没有存在过的人。 第一次放弃下船，他放弃了财富和名气。 第二次放弃下船，他放弃了生命。 人们把音乐当成一种比赛，他不在意虚名和输赢。 人们想利用他的才华致富，他不愿意让他的音乐离开他。 人们浪费了太多的时间去问“为什么”，他想活得简单点。 宁愿一生孤独，不愿随波逐流。 人可以下船，但是不能离开大海。 每个人的心中都有一片海，而他的大海是音乐，是钢琴，是那个女孩。

### 1319 有用 石头星 看过 2017-02-08 17:43:50

尤记得男主在船舱里弹琴，望着甲板上的姑娘，画面、音乐、意境如梦如幻，还有斗琴那一段。但是明明进一步就可以海阔天空，非要退一步万劫不复，孤独着自闭着，害怕离开旧时的生活，无论如何不支持这样的选择。

### 2109 有用 boliang 看过 2006-07-17 13:16:54

给大众看的艺术家电影，很多煽情与细述很不必要，但是很多人喜欢

### 1652 有用 高压电 看过 2012-10-03 02:42:18

最长的一版完全是顺着煽情的每一个Ｇ点往下走的，坏处就是高潮多了人也会厌的。另外从小就好奇男二的眼睛为什么会小范围打转。

> 更多短评 323561条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:25:10

一条船杀死一个人的音乐故事。

### 0 有用 CoCo陶可可 看过 2020-03-29 13:28:58

2020，013。

### 0 有用 猴子 看过 2019-11-13 18:53:57

普通人为了“活着”，而天才未来不再孤独

我要写影评

## 海上钢琴师的影评 · · · · · · ( 全部 9703 条 )

热门 / 最新 / 好友
老鸡｜扶立 2007-12-05 14:52:08

## 俗人理解不了的幸福

关于钢琴，关于尽头，关于彼岸，这些我都不想说。我只想说说1900这个人。 众人叫他天才，众人为之疯狂。1900，从拥有这个不平凡的名字起，就注定是个不平凡的人。目光、掌声和荣耀，平凡人可能终其一生都得不到的东西，对于天才的1900就像空气一样稀松平常。 但目光、掌声和... (展开)
18598 743 1281回应 收起
玉茗 2008-03-01 13:35:10

## 我们无处安放的孤独

有些电影是你看过之后，心中涌动万千却无从下笔，是你满脑子的思绪却不知从何整理，《海上钢琴师》就是这样一部让我欲罢不能欲言又止的电影。 看完影片之后，我的唯一感觉是孤独，真孤独。可是1900真的孤独吗？后来的很多时候，我都觉得他不孤独，他有满满的用... (展开)
9560 353 606回应 收起
江浪 2013-08-22 00:19:43

## 钢琴师为什么不肯下船

很多人看完此片，都有一个疑问：钢琴师为什么不肯下船。 如果你问错了问题，又怎么能得到正确的答案呢？ 要想搞明白钢琴师为什么死守那破船，必须先问：那是一艘怎样的船？ 那是一艘横穿大西洋的游轮，无数欧洲旧世界的人通过这艘船，摆渡到了新世界——美国。 这艘船上坐过许... (展开)
4059 77 256回应 收起
思考的猫 2007-11-13 07:38:32

## 我们都是宅男

常常，你可以听到一个北京人说，“我们”的故宫、国贸、天安门怎样怎样，听到一个上海人说，“我们”的东方之珠、新天地、外滩怎样怎样，或者另一个城市的人自豪的讲起“我们”的那么广阔的空间，仿佛一个城市都是他的世界。而实际上，我们往往舍不得在国贸的商场买一件衣服，... (展开)
1513 76 230回应 收起
pythia 2008-12-10 14:56:57

## 七宝楼台

似乎不少中国大陆观众钟爱此片，事实上托纳托雷的这部作品在西方影响力有限，得过金球的最佳原创音乐和欧洲电影奖的最佳摄影，此外乏善可陈，无非欧洲的《十面埋伏》－－浮华的形式美隔着文化差异，总是能获得一些不明就里的掌声。 　　 　　1900的形象，很容易联想起欧洲... (展开)
1028 287 393回应 收起
Xizhicat 2007-01-27 23:44:01

## ::《海上钢琴师》的哲学反思::

【1】 “我”和世界 　　 　　 　　人只有在自己的外面才能看到本体的自己。 　　 　　“我”是一个人。 　　“我”在世界之中，“我”又在世界之外。 　　“我”在世界之中，所以我能感受世界。 　　“我”在世界之外，所以我能观察世界。 　　 　　1900是一个... (展开)
1284 29 107回应 收起
我坏故我在 2005-06-18 02:37:09

## 漂流在大海上的音乐浮城

终于看完了《海上钢琴师》。 1900把自己禁锢于自己的音乐中，也同时把自己禁锢于自己的世界里——他的全部世界就是他所生活着的Virginian号豪华邮轮。 对于1900而言，音乐，是用来娱乐自己的——他永远为了自己而弹奏着，永远不让自己的音乐和自己分离。 1900的存在很特别么？... (展开)
867 57 124回应 收起
MR.X 2009-06-15 11:56:19

## 《海上钢琴师》普及片中的音乐等知识【收藏】

为了为各位《海上钢琴师》的热爱者普及片中的音乐等知识，特从Tim Roth中文网转贴本文，在此，感谢cunning姐姐为了Tim不遗余力的辛勤劳动！ 想要了解电影中1900与Jelly Roll Morton弹奏的音乐名称，多能从本文中找到解答。 郑重申明：本文绝非原创，所有信息均来自北京... (展开)
1670 36 71回应 收起

> 更多影评 9703篇

添加新讨论

## 讨论区 · · · · · ·

哇。。我觉得这片子一般。。难道真的是我自己境界... | 来自小熙哥丶 | 280 回应 | 2022-11-22 12:21:51
无感，是我有问题么？ | 来自🔆 心软的神 | 21 回应 | 2022-11-20 03:45:23
道理我都懂，为什么三更半夜男主溜进女生宿舍，偷... | 来自番茄爱西红柿 | 23 回应 | 2022-11-16 20:19:07
有没有可能最后船上的1900只是小号手的想象出来的？ | 来自WonderWhale | 36 回应 | 2022-11-16 04:19:45
1900喜欢的那个女孩哪里吸引了他，看起来长得很一... | 来自河畔星尘 | 100 回应 | 2022-11-16 04:15:22

> 去这部影片的讨论区（全部1546条）

## 关于《海上钢琴师》的问题 · · · · · · ( 全部52个 )

- 1900弹奏时有用替身吗？向会弹钢琴的同学请教下里边的钢琴演奏水平如何？ 11人回答
- 为什么很多人觉得这部电影很装X？ 36人回答

> 全部52个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 腾讯视频 免费观看
- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 【内牛满面】 (影志)
- 电影上的“三部曲”系列~~ (Black Tulip)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 羽勋~_~
  刚刚 看过
- momo
  1分钟前 看过
- 清奈
  1分钟前 看过

2824900人看过 / 565795人想看

订阅海上钢琴师的评论:
feed: rss 2.0